@@ -1,6 +1,6 @@
 /*
     asfs.c -- parted asfs filesystem support
-    Copyright (C) 1998-2000, 2007 Free Software Foundation, Inc.
+    Copyright (C) 1998-2000, 2007, 2009 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -56,24 +56,20 @@ _asfs_probe (PedGeometry* geom)
 {
 	uint32_t *block;
 	struct PartitionBlock * part;
-	int blocksize = 1, reserved = 1, prealloc = 1;
+	int blocksize = 1;
         PedSector root;
         int found = 0;
 
 	PED_ASSERT (geom != NULL, return NULL);
 	PED_ASSERT (geom->dev != NULL, return NULL);
 
-	/* Finds the blocksize, prealloc and reserved values of the partition block */
+	/* Finds the blocksize of the partition block */
 	if (!(part = ped_malloc (PED_SECTOR_SIZE_DEFAULT*blocksize))) {
 		ped_exception_throw(PED_EXCEPTION_ERROR, PED_EXCEPTION_CANCEL,
 			_("%s : Failed to allocate partition block\n"), __func__);
 		goto error_part;
 	}
 	if (amiga_find_part(geom, part) != NULL) {
-		prealloc = PED_BE32_TO_CPU (part->de_PreAlloc) == 0 ?
-			1 : PED_BE32_TO_CPU (part->de_PreAlloc);
-		reserved = PED_BE32_TO_CPU (part->de_Reserved) == 0 ?
-			1 : PED_BE32_TO_CPU (part->de_Reserved);
 		blocksize = PED_BE32_TO_CPU (part->de_SizeBlock)
 			* PED_BE32_TO_CPU (part->de_SectorPerBlock) / 128;
 	}
