@@ -96,6 +96,7 @@ struct _SunPartitionData {
 struct _SunDiskData {
 	PedSector		length; /* This is based on cyl - alt-cyl */
 	SunRawLabel		raw_label;
+	int                     cylinder_alignment;
 };
 
 static PedDiskType sun_disk_type;
@@ -196,6 +197,7 @@ sun_alloc (const PedDevice* dev)
 	PED_ASSERT (bios_geom->cylinders == (PedSector) (dev->length / cyl_size),
                     return NULL);
 	sun_specific->length = ped_round_down_to (dev->length, cyl_size);
+        sun_specific->cylinder_alignment = 1;
 
 	label = &sun_specific->raw_label;
 	memset(label, 0, sizeof(SunRawLabel));
@@ -257,6 +259,42 @@ sun_free (PedDisk *disk)
 	_ped_disk_free (disk);
 }
 
+static int
+sun_disk_set_flag (PedDisk *disk, PedDiskFlag flag, int state)
+{
+        SunDiskData *disk_specific = disk->disk_specific;
+        switch (flag) {
+        case PED_DISK_CYLINDER_ALIGNMENT:
+                disk_specific->cylinder_alignment = !!state;
+                return 1;
+        default:
+                return 0;
+        }
+}
+
+static int
+sun_disk_get_flag (const PedDisk *disk, PedDiskFlag flag)
+{
+        SunDiskData *disk_specific = disk->disk_specific;
+        switch (flag) {
+        case PED_DISK_CYLINDER_ALIGNMENT:
+                return disk_specific->cylinder_alignment;
+        default:
+                return 0;
+        }
+}
+
+static int
+sun_disk_is_flag_available (const PedDisk *disk, PedDiskFlag flag)
+{
+        switch (flag) {
+        case PED_DISK_CYLINDER_ALIGNMENT:
+               return 1;
+        default:
+               return 0;
+        }
+}
+
 static int
 _check_geometry_sanity (PedDisk* disk, SunRawLabel* label)
 {
@@ -484,7 +522,7 @@ sun_write (const PedDisk* disk)
 
         verify (sizeof *label == 512);
         memcpy (s0, label, sizeof *label);
-	bool write_ok = ped_device_write (disk->dev, s0, 0, 1);
+	int write_ok = ped_device_write (disk->dev, s0, 0, 1);
 	free (s0);
 
 	if (write_ok)
@@ -707,6 +745,15 @@ sun_get_max_primary_partition_count (const PedDisk* disk)
 	return SUN_DISK_MAXPARTITIONS;
 }
 
+static PedAlignment*
+sun_get_partition_alignment(const PedDisk *disk)
+{
+	PedSector block =
+		disk->dev->hw_geom.sectors * disk->dev->hw_geom.heads;
+
+        return ped_alignment_new(0, block);
+}
+
 static PedConstraint*
 _get_strict_constraint (PedDisk* disk)
 {
@@ -759,12 +806,15 @@ sun_partition_align (PedPartition* part, const PedConstraint* constraint)
 {
         PED_ASSERT (part != NULL, return 0);
 
-	if (_ped_partition_attempt_align (part, constraint,
-					  _get_strict_constraint (part->disk)))
-	       	return 1;
-	if (_ped_partition_attempt_align (part, constraint,
-					  _get_lax_constraint (part->disk)))
-	       	return 1;
+        SunDiskData *disk_specific = part->disk->disk_specific;
+
+        if (disk_specific->cylinder_alignment &&
+            _ped_partition_attempt_align (part, constraint,
+                                          _get_strict_constraint (part->disk)))
+                return 1;
+        if (_ped_partition_attempt_align (part, constraint,
+                                          _get_lax_constraint (part->disk)))
+                return 1;
 
 #ifndef DISCOVER_ONLY
 	ped_exception_throw (
@@ -866,47 +916,23 @@ error:
 	return 0;
 }
 
-static bool
-sun_partition_check (const PedPartition* part)
-{
-	return true;
-}
+#include "pt-common.h"
+PT_define_limit_functions (sun)
 
 static PedDiskOps sun_disk_ops = {
-	probe:			sun_probe,
-#ifndef DISCOVER_ONLY
-	clobber:		sun_clobber,
-#else
-	clobber:		NULL,
-#endif
-	alloc:			sun_alloc,
-	duplicate:		sun_duplicate,
-	free:			sun_free,
-	read:			sun_read,
-#ifndef DISCOVER_ONLY
-	write:			sun_write,
-#else
-	write:			NULL,
-#endif
+	clobber:		NULL_IF_DISCOVER_ONLY (sun_clobber),
+	write:			NULL_IF_DISCOVER_ONLY (sun_write),
 
-	partition_new:		sun_partition_new,
-	partition_duplicate:	sun_partition_duplicate,
-	partition_destroy:	sun_partition_destroy,
-	partition_set_system:	sun_partition_set_system,
-	partition_set_flag:	sun_partition_set_flag,
-	partition_get_flag:	sun_partition_get_flag,
-	partition_is_flag_available:	sun_partition_is_flag_available,
-	partition_align:	sun_partition_align,
-	partition_enumerate:	sun_partition_enumerate,
-	partition_check:	sun_partition_check,
-	alloc_metadata:		sun_alloc_metadata,
-	get_max_primary_partition_count:
-				sun_get_max_primary_partition_count,
-	get_max_supported_partition_count:
-				sun_get_max_supported_partition_count,
+	disk_set_flag:          sun_disk_set_flag,
+	disk_get_flag:          sun_disk_get_flag,
+	disk_is_flag_available: sun_disk_is_flag_available,
+
+	get_partition_alignment: sun_get_partition_alignment,
 
 	partition_set_name:		NULL,
 	partition_get_name:		NULL,
+
+	PT_op_function_initializers (sun)
 };
 
 static PedDiskType sun_disk_type = {
